#
# spec file for package python-yarl
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-yarl
Version:        1.3.0
Release:        lp152.2.6.1
Summary:        Yet another URL library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/aio-libs/yarl/
Source:         https://files.pythonhosted.org/packages/source/y/yarl/yarl-%{version}.tar.gz
# PATCH-FIX-UPSTREAM tests_overcome_bpo42967.patch bsc#[0-9]+ mcepl@suse.com
# Overcome effects of bpo#42967, which forbade mixing amps and
# semicolons in query strings as separators.
Patch0:         tests_overcome_bpo42967.patch

BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module idna >= 2.0}
# test requirements
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRequires:  python3-multidict >= 4.0
Requires:       python-idna >= 2.0
%ifpython3
Requires:       python3-multidict >= 4.0
%endif
%python_subpackages

%description
The module provides a URL class for url parsing and changing.

%prep
%autosetup -p1 -n yarl-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%{python_sitearch}/*

%changelog
* Fri Apr 23 2021 Pablo Suárez Hernández <pablo.suarezhernandez@suse.com>
- Add tests_overcome_bpo42967.patch to over effects of bpo#42967,
  which forbade mixing amps and semicolons in query strings as
  separators.
* Mon Dec 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Sun Mar  3 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.3.0
  * Fix annotations for query parameter
  * An incoming query sequence can have int variables
  * Add URL.explicit_port property
  * Give a friendlier error when port cant be converted to int
  * bool(URL()) now returns False
  * Fix annotations for build
  * Fix annotations for cached_property
  * Accept str subclasses in URL constructor
  * Forbid inheritance, replace __init__ with __new__
  * Support PEP-561 (provide type hinting marker)
* Wed Aug 29 2018 tchvatal@suse.com
- Raise multidict requirement to match up setup.py
* Sat Feb 24 2018 arun@gmx.de
- update to version 1.1.1:
  * Fix performance regression: don’t encode enmpty netloc (#170)
* Sat Feb 10 2018 arun@gmx.de
- update to version 1.1.0:
  * Make pure Python quoter consistent with Cython version (#162)
- changes from version 1.0.0:
  * Use fast path if quoted string does not need requoting (#154)
  * Speed up quoting/unquoting by _Quoter and _Unquoter classes (#155)
  * Drop yarl.quote and yarl.unquote public functions (#155)
  * Add custom string writer, reuse static buffer if available (#157)
    Code is 50-80 times faster than Pure Python version (was 4-5 times
    faster)
  * Don’t recode IP zone (#144)
  * Support encoded=True in yarl.URL.build() (#158)
  * Fix updating query with multiple keys (#160)
* Thu Jan 11 2018 arun@gmx.de
- update to version 0.18.0:
  * Fallback to IDNA 2003 if domain name is not IDNA 2008 compatible
    (#152)
* Thu Jan  4 2018 arun@gmx.de
- specfile:
  * update copyright year
  * require python-idna
- update to version 0.17.0:
  * Add idna requirement
  * update to idna 2008 and test
  * Update mypy from 0.550 to 0.560
  * Better fix for #141
* Sat Dec  9 2017 arun@gmx.de
- removed test conditional as requested in SR 555310
- enabled tests
- require pytest-runner
* Fri Dec  8 2017 arun@gmx.de
- update to version 0.16.0:
  * Fix raising TypeError by url.query_string() after
    url.with_query({}) (empty mapping) #141
* Sun Nov 26 2017 arun@gmx.de
- update to version 0.15.0:
  * Add raw_path_qs attribute (#137)
* Wed Nov 15 2017 arun@gmx.de
- update to version 0.14.2:
  * Restore strict parameter as no-op in quote/unquote
- changes from version 0.14.1:
  * Restore strict parameter as no-op for sake of compatibility with
    aiohttp 2.2
* Sun Nov 12 2017 arun@gmx.de
- update to version 0.14.0:
  * Drop strict mode (#123)
  * Fix “ValueError: Unallowed PCT %%” when there’s a “%%” in the url
    (#124)
* Tue Oct 31 2017 arun@gmx.de
- update to version 0.13.0:
  * Document encoded parameter (#102)
  * Support relative urls like ‘?key=value’ (#100)
  * Unsafe encoding for QS fixed. Encode ; char in value param (#104)
  * Process passwords without user names (#95)
- changes from version 0.12.0:
  * Properly support paths without leading slash in URL.with_path()
    (#90)
  * Enable type annotation checks
* Thu Jul 13 2017 sean.marlow@suse.com
- Initial release v0.11.0.
